import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '账号登录' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '系统首页' },
      component: () => import('@/components/admin-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '系统首页' },
          component: () => import('@/views/home/index.vue')
        },
        {
          path: '/system/role',
          meta: { title: '角色管理' },
          component: () => import('@/views/system/role/index.vue')
        },
        {
          path: '/system/role/detail',
          meta: { title: '角色信息管理' },
          component: () => import('@/views/system/role/detail.vue')
        },
        {
          path: '/system/menus',
          meta: { title: '菜单管理' },
          component: () => import('@/views/system/menus/index.vue')
        },
        {
          path: '/system/dict',
          meta: { title: '字典管理' },
          component: () => import('@/views/system/dict/index.vue')
        },
        {
          path: '/system/dictData',
          meta: { title: '字典数据管理' },
          component: () => import('@/views/system/dictData/index.vue')
        },
        {
          path: '/acccount/information',
          meta: { title: '账号信息' },
          component: () => import('@/views/acccount/information/index.vue')
        },
        {
          path: '/acccount/updatepd',
          meta: { title: '修改密码' },
          component: () => import('@/views/acccount/updatepd/index.vue')
        }
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login' && to.name != 'register') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: '/follow/v1/api/tool/token',
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
